==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/NaliczeniePobyt.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class NaliczeniePobyt extends GenericDPSObject {
    /**
     * NALICZENIE_POBYT.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * NALICZENIE_POBYT.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zadluzeniePozycjaId;

    /**
     * NALICZENIE_POBYT.DATA_OBLICZENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataObliczenia;

    /**
     * NALICZENIE_POBYT.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * NALICZENIE_POBYT.DATA_KSIEGOWANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataKsiegowania;

    /**
     * NALICZENIE_POBYT.DOLICZENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long doliczenieId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return NALICZENIE_POBYT.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * NALICZENIE_POBYT.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return NALICZENIE_POBYT.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * NALICZENIE_POBYT.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @return NALICZENIE_POBYT.DATA_OBLICZENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataObliczenia() {
        return dataObliczenia;
    }

    /**
     * NALICZENIE_POBYT.DATA_OBLICZENIA
     *
     * @param dataObliczenia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataObliczenia(Date dataObliczenia) {
        this.dataObliczenia = dataObliczenia;
    }

    /**
     * @return NALICZENIE_POBYT.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * NALICZENIE_POBYT.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return NALICZENIE_POBYT.DATA_KSIEGOWANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataKsiegowania() {
        return dataKsiegowania;
    }

    /**
     * NALICZENIE_POBYT.DATA_KSIEGOWANIA
     *
     * @param dataKsiegowania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataKsiegowania(Date dataKsiegowania) {
        this.dataKsiegowania = dataKsiegowania;
    }

    /**
     * @return NALICZENIE_POBYT.DOLICZENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDoliczenieId() {
        return doliczenieId;
    }

    /**
     * NALICZENIE_POBYT.DOLICZENIE_ID
     *
     * @param doliczenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDoliczenieId(Long doliczenieId) {
        this.doliczenieId = doliczenieId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        NaliczeniePobyt other = (NaliczeniePobyt) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()))
            && (this.getDataObliczenia() == null ? other.getDataObliczenia() == null : this.getDataObliczenia().equals(other.getDataObliczenia()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getDataKsiegowania() == null ? other.getDataKsiegowania() == null : this.getDataKsiegowania().equals(other.getDataKsiegowania()))
            && (this.getDoliczenieId() == null ? other.getDoliczenieId() == null : this.getDoliczenieId().equals(other.getDoliczenieId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        result = prime * result + ((getDataObliczenia() == null) ? 0 : getDataObliczenia().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getDataKsiegowania() == null) ? 0 : getDataKsiegowania().hashCode());
        result = prime * result + ((getDoliczenieId() == null) ? 0 : getDoliczenieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append(", dataObliczenia=").append(dataObliczenia);
        sb.append(", kwota=").append(kwota);
        sb.append(", dataKsiegowania=").append(dataKsiegowania);
        sb.append(", doliczenieId=").append(doliczenieId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/NaliczeniePobyt.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class NaliczeniePobyt extends GenericDPSObject {
    /**
     * NALICZENIE_POBYT.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * NALICZENIE_POBYT.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zadluzeniePozycjaId;

    /**
     * NALICZENIE_POBYT.DATA_OBLICZENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataObliczenia;

    /**
     * NALICZENIE_POBYT.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * NALICZENIE_POBYT.DATA_KSIEGOWANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataKsiegowania;

    /**
     * NALICZENIE_POBYT.DOLICZENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long doliczenieId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return NALICZENIE_POBYT.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * NALICZENIE_POBYT.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return NALICZENIE_POBYT.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * NALICZENIE_POBYT.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @return NALICZENIE_POBYT.DATA_OBLICZENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataObliczenia() {
        return dataObliczenia;
    }

    /**
     * NALICZENIE_POBYT.DATA_OBLICZENIA
     *
     * @param dataObliczenia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataObliczenia(Date dataObliczenia) {
        this.dataObliczenia = dataObliczenia;
    }

    /**
     * @return NALICZENIE_POBYT.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * NALICZENIE_POBYT.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return NALICZENIE_POBYT.DATA_KSIEGOWANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataKsiegowania() {
        return dataKsiegowania;
    }

    /**
     * NALICZENIE_POBYT.DATA_KSIEGOWANIA
     *
     * @param dataKsiegowania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataKsiegowania(Date dataKsiegowania) {
        this.dataKsiegowania = dataKsiegowania;
    }

    /**
     * @return NALICZENIE_POBYT.DOLICZENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDoliczenieId() {
        return doliczenieId;
    }

    /**
     * NALICZENIE_POBYT.DOLICZENIE_ID
     *
     * @param doliczenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDoliczenieId(Long doliczenieId) {
        this.doliczenieId = doliczenieId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        NaliczeniePobyt other = (NaliczeniePobyt) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()))
            && (this.getDataObliczenia() == null ? other.getDataObliczenia() == null : this.getDataObliczenia().equals(other.getDataObliczenia()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getDataKsiegowania() == null ? other.getDataKsiegowania() == null : this.getDataKsiegowania().equals(other.getDataKsiegowania()))
            && (this.getDoliczenieId() == null ? other.getDoliczenieId() == null : this.getDoliczenieId().equals(other.getDoliczenieId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        result = prime * result + ((getDataObliczenia() == null) ? 0 : getDataObliczenia().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getDataKsiegowania() == null) ? 0 : getDataKsiegowania().hashCode());
        result = prime * result + ((getDoliczenieId() == null) ? 0 : getDoliczenieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append(", dataObliczenia=").append(dataObliczenia);
        sb.append(", kwota=").append(kwota);
        sb.append(", dataKsiegowania=").append(dataKsiegowania);
        sb.append(", doliczenieId=").append(doliczenieId);
        sb.append("]");
        return sb.toString();
    }
}
